#!/bin/csh -f

# Alias conmap to conmap7
alias conmap /home/kevin/bin/pc/conmap7

# Check OS - conmap7 is not available on the SUNs (atlas, orthus)
if ($OS != linux) then
  echo "ERROR: conmap7 is only compiled for Linux PCs at this time"
  echo "Run on a Linux PC e.g. cove"
  exit
endif

if ($#argv == 0) then
  echo "Usage: plot_diff.aus.csh CMP_file"
  exit
else
  set infile = ($1)   # Assign argument 1 to infile
  echo "CMP file: "$infile  # or ${infile}
endif

# Create colour band plot (gmeta) using instruction file icon.band (answers to prompts)
conmap -k icon_k.band.diff -Bcsh $infile < icon.band.aus.diff
# Convert gmeta to Postscript (PS) (g.ps)
g2ps -c gmeta
# Save PS file (bands)
mv g.ps g_band.ps

# Create contour plot (gmeta) using instruction file icon.band (answers to prompts)
conmap -k icon_k.cont.diff -cs $infile < icon.cont.aus.diff
# Convert gmeta to Postscript (g.ps)
g2ps -c gmeta
# Save PS file (contours)
mv g.ps g_cont.ps

# Overlay contours on bands with multimet
# This is a Perl script that operates on PS files
# Note: No space between option and value
# e.g. -omult.ps not -o mult.ps
# Optionally, provide titles and captions
set topcap = ""
set toptitle = "Anomaly over Australia"
set bottitle = ""

multimet -omult.ps \
 -x0 -y0 -s1.0 g_band.ps -x0 -y0 -s1.0 g_cont.ps \
 -x53 -y565 -p14 -c"$topcap" \
 -x50 -y615 -p14 -c"$toptitle" \
 -x240 -y170 -p15 -c"$bottitle"

# Specify final plot filename
set o = gdiff.aus.png

# Convert mult.ps to g.png (PNG file)
convert -trim -density 100 mult.ps $o

echo "Input CMP file:" $infile
echo "Plot file:" $o

echo "Done\!"

exit
